@@ -10,7 +10,6 @@
 #include <KCrash>
 #include <KDBusService>
 #include <KIconTheme>
-#include <KLocalizedContext>
 #include <KLocalizedQmlContext>
 #include <KLocalizedString>
 #include <KWindowConfig>
@@ -27,6 +26,7 @@
 #include <QQuickWindow>
 
 #include <KStyleManager>
+using namespace Qt::Literals::StringLiterals;
 static void raiseWindow(QWindow *window)
 {
     KWindowSystem::updateStartupId(window);
@@ -38,21 +38,21 @@ int main(int argc, char *argv[])
     KIconTheme::initTheme();
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain(QByteArrayLiteral("merkuro"));
-    QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
-    QCoreApplication::setApplicationName(QStringLiteral("Merkuro"));
+    KLocalizedString::setApplicationDomain("merkuro"_ba);
+    QCoreApplication::setOrganizationName(u"KDE"_s);
+    QCoreApplication::setApplicationName(u"Merkuro"_s);
     QCoreApplication::setQuitLockEnabled(false);
 
     // Default to org.kde.desktop style unless the user forces another style
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
-        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+        QQuickStyle::setStyle(u"org.kde.desktop"_s);
     }
 
     KStyleManager::initStyle();
 
     KAboutData aboutData(
         // The program name used internally.
-        QStringLiteral("merkuro.calendar"),
+        u"merkuro.calendar"_s,
         // A displayable program name string.
         i18nc("@title", "Merkuro Calendar"),
         QStringLiteral(MERKURO_VERSION_STRING),
@@ -61,24 +61,21 @@ int main(int argc, char *argv[])
         // The license this code is released under.
         KAboutLicense::GPL_V3,
         // Copyright Statement.
-        i18n("© KDE Community 2021-2024"));
+        i18n("© KDE Community 2021–2024"));
     aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?format=guided&product=merkuro&version=" + QStringLiteral(MERKURO_VERSION_STRING).toUtf8());
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
-                        QStringLiteral("carl@carlschwan.eu"),
-                        QStringLiteral("https://carlschwan.eu"),
-                        QUrl(QStringLiteral("https://carlschwan.eu/avatar.png")));
+                        u"carl@carlschwan.eu"_s,
+                        u"https://carlschwan.eu"_s,
+                        QUrl(u"https://carlschwan.eu/avatar.png"_s));
     aboutData.addAuthor(i18nc("@info:credit", "Clau Cambra"),
                         i18nc("@info:credit", "Maintainer"),
-                        QStringLiteral("claudio.cambra@gmail.com"),
-                        QStringLiteral("https://claudiocambra.com"));
-    aboutData.addAuthor(i18nc("@info:credit", "Felipe Kinoshita"),
-                        i18nc("@info:credit", "Developer"),
-                        QStringLiteral("kinofhek@gmail.com"),
-                        QStringLiteral("https://fhek.gitlab.io"));
+                        u"claudio.cambra@gmail.com"_s,
+                        u"https://claudiocambra.com"_s);
+    aboutData.addAuthor(i18nc("@info:credit", "Felipe Kinoshita"), i18nc("@info:credit", "Developer"), u"kinofhek@gmail.com"_s, u"https://fhek.gitlab.io"_s);
     KAboutData::setApplicationData(aboutData);
     KCrash::initialize();
-    QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.merkuro.calendar")));
+    QGuiApplication::setWindowIcon(QIcon::fromTheme(u"org.kde.merkuro.calendar"_s));
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
@@ -103,7 +100,7 @@ int main(int argc, char *argv[])
             if (view) {
                 raiseWindow(view);
 
-                auto importer = view->findChild<Importer *>(QStringLiteral("ImportHandler"));
+                auto importer = view->findChild<Importer *>(u"ImportHandler"_s);
                 for (const auto &arg : args) {
                     Q_EMIT importer->importCalendarFromFile(QUrl::fromUserInput(arg, QDir::currentPath(), QUrl::AssumeLocalFile));
                 }
@@ -123,8 +120,8 @@ int main(int argc, char *argv[])
     for (auto obj : rootObjects) {
         const auto view = qobject_cast<QQuickWindow *>(obj);
         if (view) {
-            KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-            KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
+            KConfig dataResource(u"data"_s, KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
+            KConfigGroup windowGroup(&dataResource, u"Window"_s);
             KWindowConfig::restoreWindowSize(view, windowGroup);
             KWindowConfig::restoreWindowPosition(view, windowGroup);
 
@@ -132,7 +129,7 @@ int main(int argc, char *argv[])
 
             const auto args = parser.positionalArguments();
 
-            auto importer = view->findChild<Importer *>(QStringLiteral("ImportHandler"));
+            auto importer = view->findChild<Importer *>(u"ImportHandler"_s);
             for (const auto &arg : args) {
                 Q_EMIT importer->importCalendarFromFile(QUrl::fromUserInput(arg, QDir::currentPath(), QUrl::AssumeLocalFile));
             }
